aboutsummaryrefslogtreecommitdiffstats
path: root/yardstick/benchmark/scenarios/availability/serviceha.py
diff options
context:
space:
mode:
authorrexlee8776 <limingjiang@huawei.com>2018-07-24 04:17:45 +0000
committerrexlee8776 <limingjiang@huawei.com>2018-07-31 07:27:00 +0000
commit5f11cb9f55aa0529fddfe916a2976a9aa5b4c08f (patch)
tree9c5c83b9147a3423ba4e61cc710bd226c0b209f0 /yardstick/benchmark/scenarios/availability/serviceha.py
parent5b37f2eb188c390ce6942940e0ad9f33900dafd5 (diff)
the recovery action of "baremetal down" should be triggered mandatory
YARDSTICK-1222 has made attacker recover only when the sla not pass. But for baremetal down test case, the node need to power on even the sla pass. TODO: Make attacker can support mandatory recover in some situation. JIRA: YARDSTICK-1337 Change-Id: Ib567b9b9025e5ee421ea47140c468537ad16f090 Signed-off-by: rexlee8776 <limingjiang@huawei.com>
Diffstat (limited to 'yardstick/benchmark/scenarios/availability/serviceha.py')
-rwxr-xr-xyardstick/benchmark/scenarios/availability/serviceha.py6
1 files changed, 3 insertions, 3 deletions
diff --git a/yardstick/benchmark/scenarios/availability/serviceha.py b/yardstick/benchmark/scenarios/availability/serviceha.py
index 7f976fdbc..fdfe7cbbe 100755
--- a/yardstick/benchmark/scenarios/availability/serviceha.py
+++ b/yardstick/benchmark/scenarios/availability/serviceha.py
@@ -88,9 +88,9 @@ class ServiceHA(base.Scenario):
def teardown(self):
"""scenario teardown"""
- # only recover when sla not pass
- if not self.sla_pass:
- for attacker in self.attackers:
+ # recover when mandatory or sla not pass
+ for attacker in self.attackers:
+ if attacker.mandatory or not self.sla_pass:
attacker.recover()